@@ -57,10 +57,12 @@ count_levels <- function(dat, enum_list, hasNA= c("no", "count.obs", "count.miss
     if (grepl("Windows", utils::sessionInfo()$running)) {cl <- parallel::makeCluster(nnodes, type= "PSOCK")}
     else {cl <- parallel::makeCluster(nnodes, type= "FORK")}
     
+    parallel::clusterExport(cl, varlist= c("count_compare"))
+    
     temp <- do.call("cbind", parallel::clusterApply(cl,
           # split data across clusters, share: comparison (e2) and hasNA
           x= splitRows(dat2, nnodes), fun= function(x, e2, hasNA) {
-            return(imputeMulti:::count_compare(x= e2, dat= x, hasNA= hasNA))
+            return(count_compare(x= e2, dat= x, hasNA= hasNA))
             # wrapper function needed for parameter-name-confusion b/w clusterApply
             # and count_compare
           }, e2= e2, hasNA= hasNA))
